You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by GitBox <gi...@apache.org> on 2020/07/30 13:18:33 UTC
[GitHub] [tomcat] stokito edited a comment on pull request #325: BZ 64265 Fix and simplify weak ETag matching
stokito edited a comment on pull request #325:
URL: https://github.com/apache/tomcat/pull/325#issuecomment-661298600
At least triple fast because creates less memory garbage. For two comma separated ETags may work 10 times faster.
Here is a benchmark with results https://gist.github.com/stokito/a82eed1aef6ad965e2a279825f1c3420
I tested with force GC between tests to compare just CPU time. Note that this comparison performed for each request.
----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
For queries about this service, please contact Infrastructure at:
users@infra.apache.org
---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org